@@ -255,8 +255,11 @@ general_veh_props = {
     'name'               : {'num': -1, 'string': None},
 }
 
-def ottd_display_speed(value, divisor, unit):
-    return (round(value.value / divisor * 10 * unit.ottd_mul) >> unit.ottd_shift) // 16
+def ottd_display_speed(value, mul, div, unit):
+    # Convert value to km/h-ish.
+    kmh_ish = value.value * mul // div
+    # Duplicate OpenTTD's `ConvertKmhishSpeedToDisplaySpeed()`
+    return ((10 * kmh_ish * unit.ottd_mul) >> unit.ottd_shift) // 16
 
 class VariableListProp(BaseAction0Property):
     """
@@ -331,7 +334,7 @@ def zero_refit_mask(prop_num):
 properties[0x00] = {
     'track_type'                   : {'size': 1, 'num': 0x05},
     'ai_special_flag'              : {'size': 1, 'num': 0x08},
-    'speed'                        : {'size': 2, 'num': 0x09, 'unit_type': 'speed', 'unit_conversion': (5000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, unit)},
+    'speed'                        : {'size': 2, 'num': 0x09, 'unit_type': 'speed', 'unit_conversion': (5000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, 1, unit)},
     # 09 doesn't exist
     'power'                        : {'size': 2, 'num': 0x0B, 'unit_type': 'power'},
     # 0A doesn't exist
@@ -391,7 +394,7 @@ def roadveh_speed_prop(prop_info):
 properties[0x01] = {
     'road_type'                    : {'size': 1, 'num': 0x05},
     'tram_type'                    : {'size': 1, 'num': 0x05},
-    'speed'                        : roadveh_speed_prop({'unit_type': 'speed', 'unit_conversion': (10000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 2, unit)}),
+    'speed'                        : roadveh_speed_prop({'unit_type': 'speed', 'unit_conversion': (10000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, 2, unit)}),
     'running_cost_factor'          : {'size': 1, 'num': 0x09},
     'running_cost_base'            : {'size': 4, 'num': 0x0A},
     # 0B -0D don't exist
@@ -439,7 +442,7 @@ properties[0x02] = {
     'sprite_id'                    : {'size': 1, 'num': 0x08},
     'is_refittable'                : {'size': 1, 'num': 0x09},
     'cost_factor'                  : {'size': 1, 'num': 0x0A},
-    'speed'                        : {'size': 1, 'num': 0x0B, 'unit_type': 'speed', 'unit_conversion': (10000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 2, unit)},
+    'speed'                        : {'size': 1, 'num': 0x0B, 'unit_type': 'speed', 'unit_conversion': (10000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, 2, unit)},
     'default_cargo_type'           : {'size': 1, 'num': 0x0C},
     'cargo_capacity'               : {'size': 2, 'num': 0x0D},
     # 0E does not exist
@@ -481,7 +484,7 @@ properties[0x03] = {
     'sprite_id'                    : {'size': 1, 'num': 0x08},
     'aircraft_type'                : [{'size': 1, 'num': 0x09, 'value_function': aircraft_is_heli}, {'size': 1, 'num': 0x0A, 'value_function': aircraft_is_large}],
     'cost_factor'                  : {'size': 1, 'num': 0x0B},
-    'speed'                        : {'size': 1, 'num': 0x0C, 'unit_type': 'speed', 'unit_conversion': (701, 2507), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1 / (8 * 1.6), unit)},
+    'speed'                        : {'size': 1, 'num': 0x0C, 'unit_type': 'speed', 'unit_conversion': (701, 2507), 'adjust_value': lambda val, unit: ottd_display_speed(val, 128, 10, unit)},
     'acceleration'                 : {'size': 1, 'num': 0x0D},
     'running_cost_factor'          : {'size': 1, 'num': 0x0E},
     'passenger_capacity'           : {'size': 2, 'num': 0x0F},
@@ -709,6 +712,15 @@ def industry_layouts(value):
         layouts.append(tilelayout_names[name.value])
     return [IndustryLayoutProp(layouts)]
 
+def industry_prod_multiplier(value):
+    if not isinstance(value, Array) or len(value.values) > 2:
+        raise generic.ScriptError("Prod multiplier must be an array of up to two values", value.pos)
+    props = []
+    for i in range(0, 2):
+        val = value.values[i].reduce_constant() if i < len(value.values) else ConstantNumeric(0)
+        props.append(Action0Property(0x12 + i, val, 1))
+    return props
+
 class RandomSoundsProp(BaseAction0Property):
     def __init__(self, sound_list):
         self.sound_list = sound_list
@@ -755,6 +767,19 @@ def industry_conflicting_types(value):
         types_list.append(ConstantNumeric(0xFF))
     return [ConflictingTypesProp(types_list)]
 
+def industry_input_multiplier(value, prop_num):
+    if not isinstance(value, Array) or len(value.values) > 2:
+        raise generic.ScriptError("Input multiplier must be an array of up to two values", value.pos)
+    val1 = value.values[0].reduce() if len(value.values) > 0 else ConstantNumeric(0)
+    val2 = value.values[1].reduce() if len(value.values) > 1 else ConstantNumeric(0)
+    if not isinstance(val1, (ConstantNumeric, ConstantFloat)) or not isinstance(val2, (ConstantNumeric, ConstantFloat)):
+        raise generic.ScriptError("Expected a compile-time constant", value.pos)
+    generic.check_range(val1.value, 0, 256, "input_multiplier", val1.pos)
+    generic.check_range(val2.value, 0, 256, "input_multiplier", val2.pos)
+    mul1 = int(val1.value * 256)
+    mul2 = int(val2.value * 256)
+    return [Action0Property(prop_num, ConstantNumeric(mul1 | (mul2 << 16)), 4)]
+
 class IndustryInputMultiplierProp(BaseAction0Property):
     def __init__(self, prop_num, data):
         self.prop_num = prop_num
@@ -849,7 +874,9 @@ properties[0x0A] = {
     'prod_increase_msg'      : {'size': 2, 'num': 0x0D, 'string': 0xDC},
     'prod_decrease_msg'      : {'size': 2, 'num': 0x0E, 'string': 0xDC},
     'fund_cost_multiplier'   : {'size': 1, 'num': 0x0F},
-    'cargo_types'            : {'custom_function': industry_cargo_types}, # = prop 25+26+27+28 combined in one structure
+    'prod_cargo_types'       : {'size': 2, 'num': 0x10, 'value_function': lambda value: cargo_list(value, 2), 'replaced_by': 'cargo_types'},
+    'accept_cargo_types'     : {'size': 4, 'num': 0x11, 'value_function': lambda value: cargo_list(value, 3), 'replaced_by': 'cargo_types'},
+    'prod_multiplier'        : {'custom_function': industry_prod_multiplier, 'replaced_by': 'cargo_types'}, # = prop 12,13
     'min_cargo_distr'        : {'size': 1, 'num': 0x14},
     'random_sound_effects'   : {'custom_function': random_sounds}, # = prop 15
     'conflicting_ind_types'  : {'custom_function': industry_conflicting_types}, # = prop 16
@@ -859,11 +886,15 @@ properties[0x0A] = {
     'map_colour'             : {'size': 1, 'num': 0x19},
     'spec_flags'             : {'size': 4, 'num': 0x1A},
     'new_ind_msg'            : {'size': 2, 'num': 0x1B, 'string': 0xDC},
+    'input_multiplier_1'     : {'custom_function': lambda value: industry_input_multiplier(value, 0x1C), 'replaced_by': 'cargo_types'},
+    'input_multiplier_2'     : {'custom_function': lambda value: industry_input_multiplier(value, 0x1D), 'replaced_by': 'cargo_types'},
+    'input_multiplier_3'     : {'custom_function': lambda value: industry_input_multiplier(value, 0x1E), 'replaced_by': 'cargo_types'},
     'name'                   : {'size': 2, 'num': 0x1F, 'string': 0xDC},
     'prospect_chance'        : {'size': 4, 'num': 0x20, 'unit_conversion': 0xFFFFFFFF},
     # prop 21, 22 (callback flags) are not set by user
     'remove_cost_multiplier' : {'size': 4, 'num': 0x23},
     'nearby_station_name'    : {'size': 2, 'num': 0x24, 'string': 0xDC},
+    'cargo_types'            : {'custom_function': industry_cargo_types}, # = prop 25+26+27+28 combined in one structure
 }
 
 #
@@ -1044,7 +1075,7 @@ properties[0x10] = {
     'railtype_flags'           : {'size': 1, 'num': 0x10},
     'curve_speed_multiplier'   : {'size': 1, 'num': 0x11},
     'station_graphics'         : {'size': 1, 'num': 0x12},
-    'speed_limit'              : {'size': 2, 'num': 0x14, 'unit_type': 'speed', 'unit_conversion': (5000, 1397)},
+    'speed_limit'              : {'size': 2, 'num': 0x14, 'unit_type': 'speed', 'unit_conversion': (5000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, 1, unit)},
     'acceleration_model'       : {'size': 1, 'num': 0x15},
     'requires_railtype_list'   : {'custom_function': lambda x: label_list(x, 0x18, "Railtype")},
     'introduces_railtype_list' : {'custom_function': lambda x: label_list(x, 0x19, "Railtype")},
@@ -1073,7 +1104,7 @@ properties[0x12] = {
     **common_tracktype_props,
     'powered_roadtype_list'    : {'custom_function': lambda x: label_list(x, 0x0F, "Roadtype")},
     'roadtype_flags'           : {'size': 1, 'num': 0x10},
-    'speed_limit'              : {'size': 2, 'num': 0x14, 'unit_type': 'speed', 'unit_conversion': (10000, 1397)},
+    'speed_limit'              : {'size': 2, 'num': 0x14, 'unit_type': 'speed', 'unit_conversion': (10000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, 2, unit)},
     'requires_roadtype_list'   : {'custom_function': lambda x: label_list(x, 0x18, "Roadtype")},
     'introduces_roadtype_list' : {'custom_function': lambda x: label_list(x, 0x19, "Roadtype")},
     'alternative_roadtype_list': {'custom_function': lambda x: label_list(x, 0x1D, "Roadtype")},
@@ -1087,7 +1118,7 @@ properties[0x13] = {
     **common_tracktype_props,
     'powered_tramtype_list'    : {'custom_function': lambda x: label_list(x, 0x0F, "Tramtype")},
     'tramtype_flags'           : {'size': 1, 'num': 0x10},
-    'speed_limit'              : {'size': 2, 'num': 0x14, 'unit_type': 'speed', 'unit_conversion': (10000, 1397)},
+    'speed_limit'              : {'size': 2, 'num': 0x14, 'unit_type': 'speed', 'unit_conversion': (10000, 1397), 'adjust_value': lambda val, unit: ottd_display_speed(val, 1, 2, unit)},
     'requires_tramtype_list'   : {'custom_function': lambda x: label_list(x, 0x18, "Tramtype")},
     'introduces_tramtype_list' : {'custom_function': lambda x: label_list(x, 0x19, "Tramtype")},
     'alternative_tramtype_list': {'custom_function': lambda x: label_list(x, 0x1D, "Tramtype")},
