@@ -15,7 +15,7 @@ with NML; if not, write to the Free Software Foundation, Inc.,
 
 from nml import expression, nmlop
 
-callbacks = 0x12 * [{}]
+callbacks = 0x14 * [{}]
 
 # Possible values for 'purchase':
 # 0 (or not set): not called from purchase list
@@ -264,6 +264,7 @@ callbacks[0x10] = {
     'fences'          : {'type': 'cargo', 'num': 0x09},
     'tunnel_overlay'  : {'type': 'cargo', 'num': 0x0A},
     'signals'         : {'type': 'cargo', 'num': 0x0B},
+    'precombined'     : {'type': 'cargo', 'num': 0x0C},
 }
 
 # Airport tiles
@@ -274,3 +275,28 @@ callbacks[0x11] = {
     'anim_speed'      : {'type': 'cb', 'num': 0x154, 'flag_bit': 1},
     'default'         : {'type': 'cargo', 'num': None},
 }
+
+# Roadtypes
+callbacks[0x12] = {
+    # No default here, it makes no sense
+    'gui'             : {'type': 'cargo', 'num': 0x00},
+    'track_overlay'   : {'type': 'cargo', 'num': 0x01},
+    'underlay'        : {'type': 'cargo', 'num': 0x02},
+    'catenary_front'  : {'type': 'cargo', 'num': 0x04},
+    'catenary_back'   : {'type': 'cargo', 'num': 0x05},
+    'bridge_surfaces' : {'type': 'cargo', 'num': 0x06},
+    'depots'          : {'type': 'cargo', 'num': 0x08},
+    'roadstops'       : {'type': 'cargo', 'num': 0x0A},
+}
+
+# Tramtypes
+callbacks[0x13] = {
+    # No default here, it makes no sense
+    'gui'             : {'type': 'cargo', 'num': 0x00},
+    'track_overlay'   : {'type': 'cargo', 'num': 0x01},
+    'underlay'        : {'type': 'cargo', 'num': 0x02},
+    'catenary_front'  : {'type': 'cargo', 'num': 0x04},
+    'catenary_back'   : {'type': 'cargo', 'num': 0x05},
+    'bridge_surfaces' : {'type': 'cargo', 'num': 0x06},
+    'depots'          : {'type': 'cargo', 'num': 0x08},
+}
