@@ -13,7 +13,7 @@ You should have received a copy of the GNU General Public License along
 with NML; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
 
-class SpriteCountAction(object):
+class SpriteCountAction:
     def __init__(self, count):
         self.count = count
 
