@@ -31,3 +31,7 @@ class Array(Expression):
 
     def reduce(self, id_dicts = [], unknown_id_fatal = True):
         return Array([val.reduce(id_dicts, unknown_id_fatal) for val in self.values], self.pos)
+
+    def collect_references(self):
+        from itertools import chain
+        return list(chain.from_iterable(v.collect_references() for v in self.values))
