@@ -41,6 +41,9 @@ class BinNot(Expression):
     def supported_by_actionD(self, raise_error):
         return self.expr.supported_by_actionD(raise_error)
 
+    def collect_references(self):
+        return self.expr.collect_references()
+
     def __str__(self):
         return "~" + str(self.expr)
 
@@ -76,6 +79,9 @@ class Not(Expression):
     def supported_by_actionD(self, raise_error):
         return self.expr.supported_by_actionD(raise_error)
 
+    def collect_references(self):
+        return self.expr.collect_references()
+
     def is_boolean(self):
         return True
 
