@@ -44,6 +44,9 @@ class Boolean(Expression):
     def supported_by_actionD(self, raise_error):
         return self.expr.supported_by_actionD(raise_error)
 
+    def collect_references(self):
+        return self.expr.collect_references()
+
     def is_boolean(self):
         return True
 
