@@ -25,11 +25,11 @@ class Parameter(Expression):
             generic.print_warning("Accessing parameters out of the range 0..63 is not supported and may lead to unexpected behaviour.", pos)
 
     def debug_print(self, indentation):
-        print indentation*' ' + 'Parameter:'
+        generic.print_dbg(indentation, 'Parameter:')
         self.num.debug_print(indentation + 2)
 
     def __str__(self):
-        return 'param[%s]' % str(self.num)
+        return 'param[{}]'.format(self.num)
 
     def reduce(self, id_dicts = [], unknown_id_fatal = True):
         num = self.num.reduce(id_dicts)
@@ -62,12 +62,12 @@ class OtherGRFParameter(Expression):
         self.num = num
 
     def debug_print(self, indentation):
-        print indentation*' ' + 'OtherGRFParameter:'
+        generic.print_dbg(indentation, 'OtherGRFParameter:')
         self.grfid.debug_print(indentation + 2)
         self.num.debug_print(indentation + 2)
 
     def __str__(self):
-        return 'param[%s, %s]' % (str(self.grfid), str(self.num))
+        return 'param[{}, {}]'.format(self.grfid, self.num)
 
     def reduce(self, id_dicts = [], unknown_id_fatal = True):
         grfid = self.grfid.reduce(id_dicts)
@@ -87,8 +87,18 @@ class OtherGRFParameter(Expression):
         return True
 
 def parse_string_to_dword(string):
+    """
+    Convert string literal expression of length 4 to it's equivalent 32 bit number.
+
+    @param string: Expression to convert.
+    @type  string: L{Expression}
+
+    @return: Value of the converted expression (a 32 bit integer number, little endian).
+    @rtype:  C{int}
+    """
     if not isinstance(string, StringLiteral) or grfstrings.get_string_size(string.value, False, True) != 4:
         raise generic.ScriptError("Expected a string literal of length 4", string.pos)
+
     pos = string.pos
     string = string.value
     bytes = []
@@ -103,4 +113,5 @@ def parse_string_to_dword(string):
                 i += 1
     except ValueError:
         raise generic.ScriptError("Cannot convert string to integer id", pos)
+
     return bytes[0] | (bytes[1] << 8) | (bytes[2] << 16) | (bytes[3] << 24)
