@@ -13,6 +13,7 @@ You should have received a copy of the GNU General Public License along
 with NML; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
 
+from nml import generic
 from .base_expression import Expression
 
 class SpecialParameter(Expression):
@@ -20,10 +21,10 @@ class SpecialParameter(Expression):
     Class for handling special grf parameters.
     These can be assigned special, custom methods for reading / writing to them.
 
-    @ivar name: Name of the parameter, for debugging purposes
-    @type name: C{basestring}
+    @ivar name: Name of the parameter, for debugging purposes.
+    @type name: C{str}
 
-    @ivar info: Information about the parameter
+    @ivar info: Information about the parameter.
     @type info: C{dict}
 
     @ivar write_func: Function that will be called when the parameter is the target of an assignment
@@ -57,7 +58,7 @@ class SpecialParameter(Expression):
         self.is_bool = is_bool
 
     def debug_print(self, indentation):
-        print indentation*' ' + "Special parameter '%s'" % self.name
+        generic.print_dbg(indentation, "Special parameter '{}'".format(self.name))
 
     def __str__(self):
         return self.name
