@@ -51,6 +51,9 @@ class TernaryOp(Expression):
     def supported_by_actionD(self, raise_error):
         return self.guard.supported_by_actionD(raise_error) and self.expr1.supported_by_actionD(raise_error) and self.expr2.supported_by_actionD(raise_error)
 
+    def collect_references(self):
+        return self.guard.collect_references() + self.expr1.collect_references() + self.expr2.collect_references()
+
     def is_boolean(self):
         return self.expr1.is_boolean() and self.expr2.is_boolean()
 
