@@ -228,6 +228,8 @@ commands = {
 'DKBLUE':         {'unicode': r'\UE097',    'ascii': r'\97'},
 'BLACK':          {'unicode': r'\UE098',    'ascii': r'\98'},
 
+'PUSH_COLOUR':    {'unicode': r'\UE09A\1F', 'ascii': r'\9A\1F'},
+'POP_COLOUR':     {'unicode': r'\UE09A\20', 'ascii': r'\9A\20'},
 
 # Deprecated string codes
 'DWORD_S':        {'unicode': r'\UE07B',    'ascii': r'\7B', 'deprecated': True, 'size': 4},
@@ -261,24 +263,25 @@ def read_extra_commands(custom_tags_file):
         #Failed to open custom_tags.txt, ignore this
         return
     line_no = 0
-    for line in codecs.open(generic.find_file(custom_tags_file), "r", "utf-8"):
-        line_no += 1
-        line = line.strip()
-        if len(line) == 0 or line[0] == "#": continue
+    with open(generic.find_file(custom_tags_file), "r", encoding="utf-8") as fh:
+        for line in fh:
+            line_no += 1
+            line = line.strip()
+            if len(line) == 0 or line[0] == "#": continue
 
-        i = line.find(':')
-        if i == -1:
-            raise generic.ScriptError("Line has no ':' delimiter.", generic.LinePosition(custom_tags_file, line_no))
-        name = line[:i].strip()
-        value = line[i+1:]
-        if name in commands:
-            generic.print_warning('Overwriting existing tag "' + name + '".', generic.LinePosition(custom_tags_file, line_no))
-        commands[name] = {'unicode': value}
-        if is_ascii_string(value):
-            commands[name]['ascii'] = value
+            i = line.find(':')
+            if i == -1:
+                raise generic.ScriptError("Line has no ':' delimiter.", generic.LinePosition(custom_tags_file, line_no))
+            name = line[:i].strip()
+            value = line[i+1:]
+            if name in commands:
+                generic.print_warning('Overwriting existing tag "' + name + '".', generic.LinePosition(custom_tags_file, line_no))
+            commands[name] = {'unicode': value}
+            if is_ascii_string(value):
+                commands[name]['ascii'] = value
 
 
-class StringCommand(object):
+class StringCommand:
     """
     Instantiated string command.
 
@@ -498,7 +501,7 @@ def validate_escapes(string, pos):
                 raise generic.ScriptError("Expected 2 hexadecimal characters after '\\'", pos)
             i += 3
 
-class NewGRFString(object):
+class NewGRFString:
     """
     A string text in a language.
 
@@ -618,7 +621,7 @@ class NewGRFString(object):
                     return 'unicode'
             else:
                 if not is_ascii_string(comp): return 'unicode'
-        for case in list(self.cases.values()):
+        for case in self.cases.values():
             if case.get_type() == 'unicode':
                 return 'unicode'
         return 'ascii'
@@ -761,7 +764,7 @@ LANG_INFOS = [('af_ZA', 0x1b,  0),
 LANG_NAMES = dict((lng[0], lng[1]) for lng in LANG_INFOS)
 LANG_PLURALS = dict((lng[1], lng[2]) for lng in LANG_INFOS)
 
-class Language(object):
+class Language:
     """
     @ivar default: Whether the language is the default language.
     @type default: C{bool}
@@ -1199,8 +1202,8 @@ def parse_file(filename, default):
     """
     lang = Language(False)
     try:
-        with codecs.open(generic.find_file(filename), "r", "utf-8") as f:
-            for idx, line in enumerate(f):
+        with open(generic.find_file(filename), "r", encoding="utf-8") as fh:
+            for idx, line in enumerate(fh):
                 pos = generic.LinePosition(filename, idx + 1)
                 line = line.rstrip('\n\r').lstrip('\uFEFF')
                 # The default language is processed twice here. Once as fallback langauge
