@@ -20,10 +20,7 @@ from nml.actions import real_sprite
 try:
     from PIL import Image
 except ImportError:
-    try:
-        import Image
-    except ImportError:
-        pass
+    pass
 
 # Some constants for the 'info' byte
 INFO_RGB    = 1
@@ -58,7 +55,7 @@ def transparency_offset(info):
     else:
         return 0
 
-class SpriteEncoder(object):
+class SpriteEncoder:
     """
     Algorithms for cropping and compressing sprites. That is encoding source images into GRF sprites.
 
@@ -68,21 +65,17 @@ class SpriteEncoder(object):
     @ivar crop_sprites: Crop sprites if possible.
     @type crop_sprites: C{bool}
 
-    @ivar enable_cache: Read/write cache from/to disk.
-    @type enable_cache: C{bool}
-
     @ivar palette: Palette for encoding, see L{palette.palette_name}.
     @type palette: C{str}
 
     @ivar cached_image_files: Currently opened source image files.
     @type cached_image_files: C{dict} mapping C{str} to C{Image}
     """
-    def __init__(self, compress_grf, crop_sprites, enable_cache, palette):
+    def __init__(self, compress_grf, crop_sprites, palette):
         self.compress_grf = compress_grf
         self.crop_sprites = crop_sprites
-        self.enable_cache = enable_cache
         self.palette = palette
-        self.sprite_cache = spritecache.SpriteCache("")
+        self.sprite_cache = spritecache.SpriteCache()
         self.cached_image_files = {}
 
     def open(self, sprite_files):
@@ -108,9 +101,8 @@ class SpriteEncoder(object):
 
             source_name = "_".join(src for src in sources if src is not None)
 
-            local_cache = spritecache.SpriteCache(generic.get_cache_file(sources, ""))
-            if self.enable_cache:
-                local_cache.read_cache()
+            local_cache = spritecache.SpriteCache(sources)
+            local_cache.read_cache()
 
             for sprite_info in sprite_list:
                 count_sprites += 1
@@ -143,7 +135,7 @@ class SpriteEncoder(object):
             num_orphaned += local_cache.count_orphaned()
 
             # Only write cache if compression is enabled. Uncompressed data is not worth to be cached.
-            if self.enable_cache and self.compress_grf:
+            if self.compress_grf:
                 local_cache.write_cache()
 
             # Transfer data to global cache for later usage
@@ -189,16 +181,19 @@ class SpriteEncoder(object):
                 image_32_pos = generic.PixelPosition(cache_key[0], cache_key[1][0], cache_key[1][1])
                 alpha = pixel_stats.get('alpha', 0)
                 if alpha > 0 and (sprite_info.flags.value & real_sprite.FLAG_NOALPHA) != 0:
-                    warnings.append("{}: {:d} of {:d} pixels ({:d}%) are semi-transparent".format(str(image_32_pos), alpha, total, alpha * 100 // total))
+                    warnings.append("{}: {:d} of {:d} pixels ({:d}%) are semi-transparent, but NOALPHA is in flags".format(
+                       str(image_32_pos), alpha, total, alpha * 100 // total))
 
             if cache_key[2] is not None:
                 image_8_pos = generic.PixelPosition(cache_key[2], cache_key[3][0], cache_key[3][1])
                 white = pixel_stats.get('white', 0)
                 anim = pixel_stats.get('anim', 0)
                 if white > 0 and (sprite_info.flags.value & real_sprite.FLAG_WHITE) == 0:
-                    warnings.append("{}: {:d} of {:d} pixels ({:d}%) are pure white".format(str(image_8_pos), white, total, white * 100 // total))
+                    warnings.append("{}: {:d} of {:d} pixels ({:d}%) are pure white, but WHITE isn't in flags".format(
+                        str(image_8_pos), white, total, white * 100 // total))
                 if anim > 0 and (sprite_info.flags.value & real_sprite.FLAG_ANIM) == 0:
-                    warnings.append("{}: {:d} of {:d} pixels ({:d}%) are animated".format(str(image_8_pos), anim, total, anim * 100 // total))
+                    warnings.append("{}: {:d} of {:d} pixels ({:d}%) are animated, but ANIM isn't in flags".format(
+                        str(image_8_pos), anim, total, anim * 100 // total))
 
         return (size_x, size_y, xoffset, yoffset, compressed_data, info_byte, crop_rect, warnings)
 
