@@ -23,6 +23,8 @@ reserved = {
     'param' :               'PARAMETER',
     'cargotable' :          'CARGOTABLE',
     'railtypetable' :       'RAILTYPETABLE',
+    'roadtypetable' :       'ROADTYPETABLE',
+    'tramtypetable' :       'TRAMTYPETABLE',
     'if' :                  'IF',
     'else' :                'ELSE',
     'while' :               'WHILE',            # reserved
@@ -60,7 +62,7 @@ reserved = {
 line_directive1_pat = re.compile(r'\#line\s+(\d+)\s*(\r?\n|"(.*)"\r?\n)')
 line_directive2_pat = re.compile(r'\#\s+(\d+)\s+"(.*)"\s*((?:\d+\s*)*)\r?\n')
 
-class NMLLexer(object):
+class NMLLexer:
     """
     @ivar lexer: PLY scanner object.
     @type lexer: L{ply.lex}
@@ -241,11 +243,17 @@ class NMLLexer(object):
 
 
 
-    def build(self):
+    def build(self, rebuild = False):
         """
         Initial construction of the scanner.
         """
-        self.lexer = lex.lex(module=self)
+        if rebuild:
+            try:
+                import os
+                os.remove(os.path.normpath(os.path.join(os.path.dirname(__file__), "generated", "lextab.py")))
+            except FileNotFoundError:
+                pass
+        self.lexer = lex.lex(module=self, optimize=1, lextab='nml.generated.lextab')
 
 
     def setup(self, text, fname):
